/*
 * This file is part of Discord4J.
 *
 * Discord4J is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Discord4J is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Discord4J.  If not, see <http://www.gnu.org/licenses/>.
 */
package discord4j.core.event.domain.guild;

import discord4j.core.DiscordClient;
import discord4j.core.object.entity.Guild;
import discord4j.core.object.entity.Member;
import discord4j.core.object.util.Snowflake;
import reactor.core.publisher.Mono;

import java.util.Set;

/**
 * Dispatched as members are streamed to the client from Discord.
 * <p>
 * By default, all members in all connected guilds are requested on startup.
 *
 * @see <a href="https://discordapp.com/developers/docs/topics/gateway#guild-members-chunk">Guild Members Chunk</a>
 */
public class MemberChunkEvent extends GuildEvent {

    private final long guildId;
    private final Set<Member> members;

    public MemberChunkEvent(DiscordClient client, long guildId, Set<Member> members) {
        super(client);
        this.guildId = guildId;
        this.members = members;
    }

    public Snowflake getGuildId() {
        return Snowflake.of(guildId);
    }

    public Mono<Guild> getGuild() {
        return getClient().getGuildById(getGuildId());
    }

    public Set<Member> getMembers() {
        return members;
    }

    @Override
    public String toString() {
        return "MemberChunkEvent{" +
                "guildId=" + guildId +
                ", members=" + members +
                '}';
    }
}
